******
Design
******

.. _model-account.tax.code:

Tax Code
========

The *Account UK VAT Analysis* module provides an additional set of *Tax Codes*
for charts of accounts based on the one in the
:doc:`Account UK Module <account_uk:index>`.

.. seealso::

   The `Tax Code <account:model-account.tax.code>` concept is introduced by
   the :doc:`Account Module <account:index>`.
